Description Usage Arguments Value
Find the starting and ending time of a season
1 | find_season_range(task_list)
|
task_list |
A data frame of task generated from generate_task_list |
A data frame containing the start and end time of each season
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.